@@ -3,17 +3,18 @@
  *
  *  Copyright (c) 2007-2008 Brian Tarricone <bjt23@cornell.edu>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; version 2 of the License ONLY.
+ *  This library is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU Lesser General Public
+ *  License as published by the Free Software Foundation; version 2
+ *  of the License ONLY.
  *
- *  This program is distributed in the hope that it will be useful,
+ *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
+ *  You should have received a copy of the GNU Lesser General Public
+ *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
@@ -28,13 +29,13 @@
 #include "xfconf-channel.h"
 #include "xfconf-cache.h"
 #include "xfconf-dbus-bindings.h"
-#include "xfconf-gvaluefuncs.h"
+#include "common/xfconf-gvaluefuncs.h"
 #include "xfconf-private.h"
-#include "xfconf-marshal.h"
+#include "common/xfconf-marshal.h"
 #include "xfconf-types.h"
-#include "xfconf-common-private.h"
+#include "common/xfconf-common-private.h"
 #include "xfconf.h"
-#include "xfconf-alias.h"
+#include "common/xfconf-alias.h"
 
 #define IS_SINGLETON_DEFAULT  TRUE
 
